@@ -5,16 +5,18 @@ from uuid import UUID
 # Override Bandit warnings, since we use this to generate XML, not parse
 from xml.etree.ElementTree import Element, SubElement, tostring  # nosec
 
-import httpx
 from semver import VersionInfo
 
 from .models import (
     ChannelMessageList,
     ChannelMessageModel,
+    ChannelMessageResponseModel,
     ChannelModel,
     ChannelStatistics,
+    MirthErrorMessageModel,
 )
 from .utils import deprecated
+from .exceptions import MirthPostError
 
 if TYPE_CHECKING:
     from .mirth import MirthAPI
@@ -36,6 +38,27 @@ def build_channel_message(raw_data: Optional[str], binary: bool = False) -> str:
     return tostring(root, encoding="unicode")
 
 
+def raise_post_errors(received: ChannelMessageModel) -> None:
+    """Raise errors from Mirth POST response
+
+    Args:
+        received (ChannelMessageModel): Mirth POST response message
+
+    Raises:
+        MirthPostError: If the Mirth POST response contains an error
+    """
+    for connector_message in received.connector_messages.values():
+        if connector_message.status == "ERROR":
+            if connector_message.response and connector_message.response.content:
+                error_response_content = MirthErrorMessageModel.parse_raw(
+                    connector_message.response.content, content_type="xml"
+                )
+                error_message = error_response_content.message
+            else:
+                error_message = f"Error Code {connector_message.error_code}"
+            raise MirthPostError(f"Error posting to Mirth: {error_message}")
+
+
 class Channel:
     """Class corresponding to a Mirth channel"""
 
@@ -160,22 +183,41 @@ class Channel:
         )
         return ChannelMessageModel.parse_raw(response.text, content_type="xml")
 
-    async def post_message(self, data: Optional[str] = None) -> httpx.Response:
+    async def post_message(
+        self, data: Optional[str] = None, raise_errors: bool = True
+    ) -> ChannelMessageModel:
         """Send a new message to the channel
 
         Args:
             data (Optional[str], optional): Raw data to send to the channel. Defaults to None.
 
         Returns:
-            httpx.Response: Mirth API response
+            int: Sent message ID
         """
         message: str = build_channel_message(data)
-        return await self.mirth.post(
+        response = await self.mirth.post(
             self.post_message_path,
             content=message,
             content_type="application/xml",
         )
 
+        msg_id = ChannelMessageResponseModel.parse_raw(
+            response.text, content_type="xml"
+        ).long
+
+        received = await self.get_message(str(msg_id), include_content=False)
+
+        # This should never happen, but handle anyway for the sake of MyPy
+        if not received:
+            raise MirthPostError(
+                "Error posting to Mirth: Sent message is missing from Mirth"
+            )
+
+        if raise_errors:
+            raise_post_errors(received)
+
+        return received
+
     # Deprecated function aliases
     @deprecated
     async def get(self) -> ChannelModel:  # pylint: disable=missing-function-docstring
